.. change::
    :tags: bug, sql
    :versions: 1.2.0

    Added :func:`.nullsfirst` and :func:`.nullslast` as top level imports
    in the ``sqlalchemy.`` and ``sqlalchemy.sql.`` namespace.  Pull request
    courtesy Lele Gaifax.